macro_rules! abort {
($code:expr, $($t:tt)*) => { ... };
}Expand description
Exit the process with the given exit code and error string to be printed to standard error.
macro_rules! abort {
($code:expr, $($t:tt)*) => { ... };
}Exit the process with the given exit code and error string to be printed to standard error.